searchData={"items":[{"type":"module","title":"PubSub","doc":"Publish-Subscribe utility process. Use `start_link/0` to start it:\n\n    PubSub.start_link()","ref":"PubSub.html"},{"type":"function","title":"PubSub.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"PubSub.html#child_spec/1"},{"type":"function","title":"PubSub.init/1","doc":"","ref":"PubSub.html#init/1"},{"type":"type","title":"PubSub.message/0","doc":"","ref":"PubSub.html#t:message/0"},{"type":"function","title":"PubSub.publish/2","doc":"Delivers a message to the given topic.","ref":"PubSub.html#publish/2"},{"type":"function","title":"Example - PubSub.publish/2","doc":"iex> PubSub.publish(:my_topic, \"Hi there!\")\n    :ok","ref":"PubSub.html#publish/2-example"},{"type":"function","title":"PubSub.start_link/1","doc":"Starts the server.","ref":"PubSub.html#start_link/1"},{"type":"function","title":"PubSub.subscribe/2","doc":"Subscribes a process to the given topic.","ref":"PubSub.html#subscribe/2"},{"type":"function","title":"Example - PubSub.subscribe/2","doc":"iex> pid = self()\n    iex> PubSub.subscribe(pid, :my_topic)\n    :ok","ref":"PubSub.html#subscribe/2-example"},{"type":"function","title":"PubSub.subscribers/1","doc":"Returns a list of pids representing the processes that are currently\nsubscribed to the given topic.","ref":"PubSub.html#subscribers/1"},{"type":"function","title":"Example - PubSub.subscribers/1","doc":"iex> pid = self()\n    iex> PubSub.subscribe(pid, :my_topic)\n    iex> [subscriber] = PubSub.subscribers(:my_topic)\n    iex> subscriber == pid\n    true","ref":"PubSub.html#subscribers/1-example"},{"type":"type","title":"PubSub.topic/0","doc":"","ref":"PubSub.html#t:topic/0"},{"type":"function","title":"PubSub.topics/0","doc":"Returns a list of the current topics.","ref":"PubSub.html#topics/0"},{"type":"function","title":"Example - PubSub.topics/0","doc":"iex> pid = self()\n    iex> PubSub.subscribe(pid, :my_topic)\n    iex> PubSub.subscribe(pid, :your_topic)\n    iex> PubSub.topics\n    [:my_topic, :your_topic]","ref":"PubSub.html#topics/0-example"},{"type":"function","title":"PubSub.unsubscribe/2","doc":"Unsubscribes a process from a given topic.","ref":"PubSub.html#unsubscribe/2"},{"type":"function","title":"Example - PubSub.unsubscribe/2","doc":"iex> pid = self()\n    iex> PubSub.unsubscribe(pid, :my_topic)\n    :ok","ref":"PubSub.html#unsubscribe/2-example"},{"type":"extras","title":"Elixir Publish/Subscribe","doc":"# Elixir Publish/Subscribe\n\n[![Build Status](https://app.travis-ci.com/simonewebdesign/elixir_pubsub.svg?branch=main)](https://app.travis-ci.com/simonewebdesign/elixir_pubsub) [![Coverage Status](https://coveralls.io/repos/github/simonewebdesign/elixir_pubsub/badge.svg?branch=main)](https://coveralls.io/github/simonewebdesign/elixir_pubsub?branch=main) [![Hex package](https://img.shields.io/hexpm/v/pubsub.svg)](https://hex.pm/packages/pubsub) [![Documentation](https://inch-ci.org/github/simonewebdesign/elixir_pubsub.svg?branch=main)](https://inch-ci.org/github/simonewebdesign/elixir_pubsub) [![Total Downloads](https://img.shields.io/hexpm/dt/pubsub.svg)](https://hex.pm/packages/pubsub)\n\nA Publish/Subscribe utility module that frees your business logic processes from the burden of communication.","ref":"readme.html"},{"type":"extras","title":"Getting Started - Elixir Publish/Subscribe","doc":"Add `:pubsub` as a dependency to your `mix.exs` file:\n\n``` elixir\ndefp deps do\n  [\n    {:pubsub, \"~> 1.0\"}\n  ]\nend\n```\n\nThen run `mix deps.get` in your shell to fetch the dependencies.","ref":"readme.html#getting-started"},{"type":"extras","title":"Examples - Elixir Publish/Subscribe","doc":"Assuming your client process looks like this:\n\n``` elixir\ndefmodule Client do\n\n  def start(client_name) do\n    spawn(fn -> loop(client_name) end)\n  end\n\n  def loop(name) do\n    receive do\n      message ->\n        IO.puts \"#{name} received `#{message}`\"\n        loop(name)\n    end\n  end\n\nend\n```\n\nWith `PubSub` you can do this:\n\n``` elixir\niex(1)> {topic1, topic2} = {:erlang, :elixir}\n{:erlang, :elixir}\n\niex(2)> {:ok, pid} = PubSub.start_link()\n{:ok, #PID<0.99.0>}\n\niex(3)> {pid1, pid2, pid3} =\n...(3)> {\n...(3)> Client.start(\"John\"),\n...(3)> Client.start(\"Nick\"),\n...(3)> Client.start(\"Tim\")\n...(3)> }\n{#PID<0.106.0>, #PID<0.107.0>, #PID<0.108.0>}\n\niex(4)> PubSub.subscribe(pid1, topic1)\n:ok\niex(5)> PubSub.subscribe(pid2, topic1)\n:ok\niex(6)> PubSub.subscribe(pid3, topic2)\n:ok\n\niex(7)> PubSub.publish(topic1, \"#{topic1} is great!\")\n\"Nick received `erlang is great!`\"\n\"John received `erlang is great!`\"\n:ok\n\niex(8)> PubSub.publish(topic2, \"#{topic2} is so cool, dude\")\n\"Tim received `elixir is so cool, dude`\"\n:ok\n```","ref":"readme.html#examples"},{"type":"extras","title":"API Reference - Elixir Publish/Subscribe","doc":"https://hexdocs.pm/pubsub/PubSub.html","ref":"readme.html#api-reference"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}